Struct leetcode_cli::cache::models::Problem [−][src]
pub struct Problem {
pub category: String,
pub fid: i32,
pub id: i32,
pub level: i32,
pub locked: bool,
pub name: String,
pub percent: f32,
pub slug: String,
pub starred: bool,
pub status: String,
pub desc: String,
}Expand description
Problem model
Fields
category: Stringfid: i32id: i32level: i32locked: boolname: Stringpercent: f32slug: Stringstarred: boolstatus: Stringdesc: StringTrait Implementations
impl<'update> AsChangeset for &'update Problem[src]
impl<'update> AsChangeset for &'update Problem[src]type Changeset = <(Eq<category, &'update String>, Eq<fid, &'update i32>, Eq<level, &'update i32>, Eq<locked, &'update bool>, Eq<name, &'update String>, Eq<percent, &'update f32>, Eq<slug, &'update String>, Eq<starred, &'update bool>, Eq<status, &'update String>, Eq<desc, &'update String>) as AsChangeset>::Changeset
type Changeset = <(Eq<category, &'update String>, Eq<fid, &'update i32>, Eq<level, &'update i32>, Eq<locked, &'update bool>, Eq<name, &'update String>, Eq<percent, &'update f32>, Eq<slug, &'update String>, Eq<starred, &'update bool>, Eq<status, &'update String>, Eq<desc, &'update String>) as AsChangeset>::ChangesetThe update statement this type represents
fn as_changeset(self) -> Self::Changeset[src]
fn as_changeset(self) -> Self::Changeset[src]Convert self into the actual update statement being executed
impl<'update> AsChangeset for Problem[src]
impl<'update> AsChangeset for Problem[src]type Changeset = <(Eq<category, String>, Eq<fid, i32>, Eq<level, i32>, Eq<locked, bool>, Eq<name, String>, Eq<percent, f32>, Eq<slug, String>, Eq<starred, bool>, Eq<status, String>, Eq<desc, String>) as AsChangeset>::Changeset
type Changeset = <(Eq<category, String>, Eq<fid, i32>, Eq<level, i32>, Eq<locked, bool>, Eq<name, String>, Eq<percent, f32>, Eq<slug, String>, Eq<starred, bool>, Eq<status, String>, Eq<desc, String>) as AsChangeset>::ChangesetThe update statement this type represents
fn as_changeset(self) -> Self::Changeset[src]
fn as_changeset(self) -> Self::Changeset[src]Convert self into the actual update statement being executed
impl<'ident> Identifiable for &'ident Problem[src]
impl<'ident> Identifiable for &'ident Problem[src]impl<'insert> Insertable<table> for Problem[src]
impl<'insert> Insertable<table> for Problem[src]type Values = <(Option<Eq<category, String>>, Option<Eq<fid, i32>>, Option<Eq<id, i32>>, Option<Eq<level, i32>>, Option<Eq<locked, bool>>, Option<Eq<name, String>>, Option<Eq<percent, f32>>, Option<Eq<slug, String>>, Option<Eq<starred, bool>>, Option<Eq<status, String>>, Option<Eq<desc, String>>) as Insertable<table>>::Values
type Values = <(Option<Eq<category, String>>, Option<Eq<fid, i32>>, Option<Eq<id, i32>>, Option<Eq<level, i32>>, Option<Eq<locked, bool>>, Option<Eq<name, String>>, Option<Eq<percent, f32>>, Option<Eq<slug, String>>, Option<Eq<starred, bool>>, Option<Eq<status, String>>, Option<Eq<desc, String>>) as Insertable<table>>::ValuesThe VALUES clause to insert these records Read more
fn insert_into(
self,
table: T
) -> InsertStatement<T, Self::Values, Insert, NoReturningClause>[src]
fn insert_into(
self,
table: T
) -> InsertStatement<T, Self::Values, Insert, NoReturningClause>[src]Insert self into a given table. Read more
impl<'insert> Insertable<table> for &'insert Problem[src]
impl<'insert> Insertable<table> for &'insert Problem[src]type Values = <(Option<Eq<category, &'insert String>>, Option<Eq<fid, &'insert i32>>, Option<Eq<id, &'insert i32>>, Option<Eq<level, &'insert i32>>, Option<Eq<locked, &'insert bool>>, Option<Eq<name, &'insert String>>, Option<Eq<percent, &'insert f32>>, Option<Eq<slug, &'insert String>>, Option<Eq<starred, &'insert bool>>, Option<Eq<status, &'insert String>>, Option<Eq<desc, &'insert String>>) as Insertable<table>>::Values
type Values = <(Option<Eq<category, &'insert String>>, Option<Eq<fid, &'insert i32>>, Option<Eq<id, &'insert i32>>, Option<Eq<level, &'insert i32>>, Option<Eq<locked, &'insert bool>>, Option<Eq<name, &'insert String>>, Option<Eq<percent, &'insert f32>>, Option<Eq<slug, &'insert String>>, Option<Eq<starred, &'insert bool>>, Option<Eq<status, &'insert String>>, Option<Eq<desc, &'insert String>>) as Insertable<table>>::ValuesThe VALUES clause to insert these records Read more
fn insert_into(
self,
table: T
) -> InsertStatement<T, Self::Values, Insert, NoReturningClause>[src]
fn insert_into(
self,
table: T
) -> InsertStatement<T, Self::Values, Insert, NoReturningClause>[src]Insert self into a given table. Read more
impl<__DB: Backend, __ST> Queryable<__ST, __DB> for Problem where
(String, i32, i32, i32, bool, String, f32, String, bool, String, String): Queryable<__ST, __DB>, [src]
impl<__DB: Backend, __ST> Queryable<__ST, __DB> for Problem where
(String, i32, i32, i32, bool, String, f32, String, bool, String, String): Queryable<__ST, __DB>, [src]impl<'insert> UndecoratedInsertRecord<table> for Problem[src]